# A Breathless And Brief Introduction To Stand Development


**WARNING**:  *What follows is for the advanced darkroom practitioner.
              It is not for beginners and people should be well
              acquainted with safety and good darkroom practices.
              If you do not already have a least one film/developer
              combination "dialed in", don't bother with any of this.*

I've been a black and white silver photographer for over four decades.
In that time, I've worked with a large number of films and developers,
eventually settling down on a few combinations that worked well for
me.  In every case, I managed time and temperature and agitated the
film according to the developer manufacturer's instructions.

Recently, I became aware of a newish staining developer called "Pyrocat-HD",
invented by Sandy King.  This developer has a great many claimed
virtues among them:

* Semi compensating in the highlights with VC papers
* Tight grain comparable to PMK Pyro
* Much lower sensitivity to oxidation effects than PMK Pyro
* Much less fussy about agitation than PMK Pyro
* Produces negatives that work well for both traditional silver and alternative printing processes

This monograph is *not* about Pyrocat-HD, although all the testing was
done with it.  Pyrocat-HD turned out to be a gateway drug to my
learning about "stand" or "still" development.  This is an an old
technique used by some of the masters like Atget.  Today's modern
masters like Sandy King and Steve Sherman are making use of variations
of stand development to great advantage.  But, in the words of Sandy
King, "It is fraught with danger". The technique is tricky and prone
to failing rather horribly.  So ... **don't try this with pictures
that matter to you without making backup negatives.** I promise you're
going to mess some of them up.

## Why Bother?

When stand (or one of its variants) works, it gives you negatives of
great apparent accutance, full box ASA speed and - this was most
important to me - a way to increase mid-tone contrast without blowing
out the highlights.  It is mid-tone contrast that gives prints that
"snap" we're always looking for. David Kachel has a very good
commentary on this:

[The Primacy Of Local Contrast](http://davidkachel.com/wpNewDK/wp-content/uploads/2019/05/PrimacyOfLocalContrast.pdf)

For example, I recently shot a scene in which the darkest shadows were
on Zone III, and the brightest highlights (snow) were well into Zone
VIII.  Depending on how you do exposure control, this is either normal
development or slight N-.  The problem is that the dominant geometry
in the scene was a bunch of boards that - at best - showed a Subject
Brightness Range of about 3 stops.  This was the most important part of
the scene but, I was stuck with two bad choices:

- Normal, or worse still, contracted development would shove all these
  tones together to produce low local contrast in the mid-tones.
  i.e., A picture that held the entire tonal range, but boring because
  the primary image geometry had low local contrast.

- But if I did N+ development to improve middle tone contrast there
  was good chance the snow highlights would blow out to Zone IX or X.
  Because Pyrocat-HD is a semi-compensating developer, I likely would
  have been able to burn through this *if* I could control the burn
  geometry properly.

This is where a form of stand saved the day.  By developing the negative
using stand techniques, I was able to get full box film speed in the shadows,
jack up the mid-tone contrast, and preserve the highlights from getting
pushed up too far.

When reading about stand development, you'll run into a lot of
discussion of "edge effects".  These occur as a byproduct of the way
stand works chemically, especially when using Pyro staining
developers.  The edge effects show up as a line in a transition
between a light and dark subject.  In the extreme case, it can
actually manifest itself as a "halo" behind the transition.  This is
one of the reasons you don't want to overdo stand development.  This
edge effect is perceived by the human eye as higher accutance or
sharpness.  It's sort of an illusion, but it's a useful one.  (For
those of you who do digital post processing, this is approximately the
chemical equivalent of an unsharp mask.)

## So How Does It Work?

Stand techniques depend on a basic property of how film develops -
*The highlights develop much faster than the shadows.* One Kodak
engineer was heard to say that "Development ends after 3 minutes, the
rest of the time is spent increasing contrast." This is just another
way of saying the same thing.

As the highlights develop, they exhaust the developer around them much
faster than the shadow areas do.  In other words, the brighter the
object - say white snow - the quicker it will exhaust the nearby
developer.  The darker the object - say a shadow - the slower it will
exhaust.  Mid-Tones live, well, somewhere in the middle.

For those of you with a technical bent, I highly recommend a careful
reading of this explanation of film behavior by David Kachel:

[How Film Works](http://davidkachel.com/wpNewDK/wp-content/uploads/2019/05/HowFilmWorks.pdf)

Normally, we don't notice this because *we agitate regularly* thereby
replenishing the supply for fresh developer everywhere, most
especially the highlights that have "run out of" useful developer.

Stand development exploits this by ... *not agitating at all or very
little*.  Highlights are allowed to exhaust because they develop
quickly and don't really need more developer.  But by letting the film
sit in a really dilute developer solution for a looooooong time
without agitation, the shadows continue to develop and so do the mid
tones.  This means we are:

* Fully developing the shadows (getting full box speed ASA)
* Raising the H/D contrast curve for the mid-tones
* Doing little to the highest tones

In effect, stand techniques add two other things we can control about
how we develop film.  In addition to time and temperature, we now add
developer dilution and frequency/duration of agitation as development
controls.

It's worth mentioning that this is super tricky to get right.  In
the words of a retired Kodak film engineer, "Kodak did not consider
still development in formulating its films. It is not a recommended
practice."  That's right, it's not.  And you're not supposed to
tune your stock Ford engine to produce more horsepower either.  It
is not recommended by the manufacturer ;)

## What's The Downside?

As film develops, it produces chemical byproducts like bromides that
we usually don't notice because ... we're agitating regularly. This
serves to "wash away" these byproducts with fresh developer.  But when
you stand develop, these byproducts can come to rest on your negative
and interfere with the development.  This results in streaks and marks
on your negatives and can be entirely ruinous to the process.  That's
why the Great Yellow Father, Kodak, recommended so strongly against
this approach.  This mess is often referred to as "bromide drag".

All manner of techniques exist to avoid these problems, with varying degrees
of success.  Among them include:

* Developing and standing negatives in open trays
* Using specialty tubes made of PVC plumber's pipe to hold the negative during standing
* Using minimal contact hangers to hold the film during standing

Formally and properly, stand development should be done with the
negatives laying flat in a tray or the equivalent.  They should *stand
laying down* not hanging vertically in a tank.  My testing suggests
that this is not absolutely necessary and at least one other approach
will work.

It's also worth noting that the photographers who pioneered this
approach a hundred plus years ago were using very different films and
plates.  Modern thin films do have more a propensity for bromide drag
than their grandfather films did.

Still, this can be conquered and - at least in my view - should be in the
arsenal of tools for any advanced monochrome silver photographer.

## Terminology

There are many references to this sort of development in the literature
and the terminology isn't used consistently.  For our purposes we'll
define things as follows:

* **Normal Development** - Using developer at recommended dilutions and
  agitating regularly once or twice a minute.

* **Stand Development** - Using highly dilute developer, agitating
  vigorously for the first 1-2 minutes and then just letting the film
  sit untouched in the developer for 45-60 minutes or even more.

* **Semistand Development** - Using highly dilute developer, agitating
  vigorously for the first 1-2 minutes, and then once again for 10-15
  seconds at the development halfway point. So, for a 60 min stand,
  we'd agitate at the 30 min mark.

* **Extreme Minimal Agitation (EMA)** (Attributed to Steve
  Sherman). Using highly dilute developer, agitating for the first 1-2
  minutes, and then again for 10-15 seconds at 2 or 3 evenly spaced
  intervals for the remaining time.  Say we initially agitate for 2
  minutes and want a total development time 30 minutes.  We could
  split up the remaining 28 minutes into three intervals and do 10-15
  second agitations at 9 minutes, 16 minutes, and 23 minutes.

Semistand and EMA were conceived to overcome the nasty development
artifacts (artefacts if you live in the UK ;) like bromide drag.  The
occasional short agitation during stand development reduces the
likelihood you'll see these gremlins appear in your negatives.

Much to my surprise, as I tested, I discovered that even the single
midpoint agitation of a semistand development can significantly
increase apparent contrast and - in the case of Pyrocat-HD - level of
stain (as well as Film Base Plus Fog). So each of these techniques
has a place.

## How Did I Test?

I exposed and developed a variety of films using all four of the
development techniques above.  As I did so (and failed more often than
not) I began to do my down "dialing it" of what worked and what did
not.

* For all cases, I used Pyrocat-HD as the developer at a nominal
  68F/20C.

  I should mention that I designed and built my own
  temperature-sensitive timer to keep temperature considerations out
  of mind in the darkroom.  You can find the details here:

  [Devtimer](https://gitbucket.tundraware.com/tundra/devtimer)

  This is certainly not a requirement and you can do ordinary
  time/temperature corrections as usual in your own work.

* Pyrocat-HD is a developer mixed from two stock solutions. Dilution
  is expressed as `Part A : PartB : Water`.  For Normal development,
  dilution was `1:1:100`.  For the various stand tests, dilution
  was either `1.5:1:150` or `1.5:1:200`.

* Developer and fixer were mixed with distilled water.

*  Films tested included  Kodak TXT, Agfapan APX 100, and Ilford FP4+ in 4x5
   sheets.  I also used 35mm Tri-X and Agfapan APX 100 for testing.

* Development was in open tanks and - in a few cases - a Yankee 4x5
  tank with insert.

* A variety of different film suspension systems were tried including
  Kodak "framed" film hangars, a Yankee 4x5 tank, and a "frameless"
  Kodak film hanger.

* Film was presoaked for 5 minutes in running water to wash off the
  anti-halation layer and prepare the emulsion to accept developer.
  It's not clear this is entirely necessary with open tanks but it
  does no harm.


## What I Have Discovered

First of all, these are **my** findings, built on my workflow and darkroom
technique. These are intended to be guideposts, not definitive rules. They
are intended to be a starting point for you to explore, not some final
word in how to do this stuff.  Every statement below should be read
to say "In my case ..."

* Stand development is *really* fussy about how the film is held in
  the developer.  Framed hangers and the Yankee tank insert all showed
  bromide drag effects in varying and unpredictable ways.  My theory -
  which I cannot prove - is that turbulent effects and developer
  trapping is taking place along- and under the hangar frames/insert
  supports and promoting bromide drag.

* Semistand development is at lower risk of this, but still shows
  some evidence of bromide drag with framed hangers and tank inserts.

* For this reason, all my sheet film is now hung using old frameless
  Kodak hangers. They have minimal points of contact with the film.
  A likely viable alternative here would be a dental X-ray film clip.
  In either case, having more than one sheet in the tank will be
  tricky to agitate because there is no frame to keep it in place.
  Patience is your friend here.

  How good is this?  I was able to get a perfect negative with Stand
  development (no agitation during stand period) using these hangers.

* I did some testing with 35mm on stainless steel reels, but dunked
  into open 4x5 tanks rather than the usual daylight tanks favored by
  small format shooters. (I did not try 120 rollfilm.)  As expected,
  Normal development worked fine.  To my surprise, Semistand was OK as
  well.  I was expecting bromide drag problems because of the way the
  reels support the film.  Again, I think strong initial agitation
  helped here.  I've also noticed a considerable difference of reel
  spacing from different manufacturers.  If you are going to do 35mm
  this way, I'd stick with the old Nikor reels.  They're a bit
  expensive but widely available on eBay.

* Stand and Semistand did best with the `1.5:1:200` dilution.  EMA did
  best with the `1.5:1:150` dilutions.  This makes sense, since EMA
  times tend to be a lot shorter than true stand development and
  more   dilute developers will take longer to act on the shadows.

* Both Stand and Semistand really need 45-60 minutes to fully do their
  jobs.

* Both Stand and Semistand need a full 2 minutes of initial agitation
  and it needs to be "vigorous".  Again, I suspect - but cannot prove -
  that really kicking the development off hard at the beginning, reduces
  the likelihood of bromide drag later.

* EMA was fine with only 90 seconds of more normal initial agitation.

* The single agitation introduced at the midpoint in Semistand
  development seems to noticeably reduce the risk of bromide
  drag.

* The single agitation introduced by Semistand development seems to
  noticeably increase overall contrast and density as compared to a
  no-agitation Stand period.  It's not night and day, but given that
  doing this reduces the risk of bromide drag, it's probably the
  preferred long stand technique and this extra contrast has to be
  considered.

* Given a normal dilution of `1:1:100` and an EMA dilution of `1:1.5:150`,
  I found that a good first order guess for EMA development time was
  to double my Normal development time with 2 equally spaced
  agitations during the stand time.

* You can do contrast control with EMA much like you do with Normal
  development - increase- or decrease overall time.  With Stand and
  Semistand, it's a bit more difficult because you really want that
  long development time to fill in the shadows and crank up the mid-tones.
  I've not tried it, but changing developer dilution is likely a better
  tactic for these development methods.

* You can overdo this. If you have a scene that already has good
  mid-tone local contrast, these techniques can give you a  cartoon-like
  local contrast expansion.

* All the stand techniques gave me full box speed ASA for every film
  I tried.

* You have to be merciless to "expose for the shadows" properly.  If
  you underexpose, nothing can save you. You cannot develop content
  that isn't present in the negative.  If you overexpose, you will get
  the entire tonal range of the image sliding up the H/D curve in ugly
  ways with stand techniques.  In this regard, exposure control and
  ASA management is much more demanding than most conventional
  film-developer Normal development methods.


## Is It Worth It?

Yes, in certain cases.  Stand is slow and finicky.  But, it really
shines when you want to emphasize mid-tone local contrast, but have a
competing highlight that would get blown out (or hard to print) if you
just did N+ Development.

More generally, these techniques are great when you need to get
maximum shadow detail, but reign in highlight placement.

Stand techniques also work nicely when you want to get best apparent
sharpness on subjects that show a lot of bright-to-dark transition
lines - for example, articulated rock faces.

Think of stand as another arrow in your quiver.  You won't always use it, but
it can be a really nice enhancement to your arsenal of tools.

I **strongly** recommend that, if you're going to try this, take at
least two exposures of every scene you care about.  Try one with stand
techniques, and have a backup you can process normally if needed.

## Copyright And Use

All content here is Copyright (c) 2021 TundraWare Inc., Des Plaines, IL USA

Permission is hereby granted for non-commercial redistribution by any
means so long as you agree to these conditions:

* You agree to hold TundraWare Inc. harmless for any damage these
  techniques may cause.

* You agree to reproduce this monograph in full with full attribution
  of authorship.

* You agree to include the URL of this monograph in your copy.
